fieldset

package
v0.5.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package fieldset provides HTML fieldset components with flexible props. The Props type defines attributes for the component, including Aria and Data props. The component renders a <fieldset> element using the provided attributes and children.

Copyright 2025 Deirror. All rights reserved. Use of this source code is governed by a MIT-style license that can be found in the LICENSE file.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Fieldset

func Fieldset(ps ...Props) templ.Component

Types

type Props

type Props struct {
	props.Attrs

	Aria aria.Props
	Data data.Props
}

func (Props) AsTemplAttrs

func (p Props) AsTemplAttrs() templ.Attributes

Jump to