label

package
v0.5.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package label provides HTML label components with flexible props. The Props type defines attributes for the component, including Aria and Data props, along with the For attribute to associate the label with a form control. The component renders a <label> element using the provided attributes and children.

Copyright 2025 Deirror. All rights reserved. Use of this source code is governed by a MIT-style license that can be found in the LICENSE file.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Label

func Label(ps ...Props) templ.Component

Types

type Props

type Props struct {
	props.Attrs

	Aria aria.Props
	Data data.Props

	For string
}

func (Props) AsTemplAttrs

func (p Props) AsTemplAttrs() templ.Attributes

Jump to