Documentation
¶
Overview ¶
Package header provides HTML header components. The Props type defines attributes for the component. The component renders a <header> element using the provided attributes and children.
Copyright 2025 Deirror. All rights reserved. Use of this source code is governed by a MIT-style license that can be found in the LICENSE file.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Props ¶
func (Props) AsTemplAttrs ¶
func (p Props) AsTemplAttrs() templ.Attributes
Click to show internal directories.
Click to hide internal directories.