mainx

package
v0.5.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package main provides HTML main components. The Props type defines attributes for the component. The component renders a <main> element using the provided attributes and children.

Copyright 2025 Deirror. All rights reserved. Use of this source code is governed by a MIT-style license that can be found in the LICENSE file.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Main

func Main(ps ...Props) templ.Component

Types

type Props

type Props struct {
	props.Attrs
}

func (Props) AsTemplAttrs

func (p Props) AsTemplAttrs() templ.Attributes

Jump to