table

package
v0.5.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package table provides HTML table components. The Props type defines attributes for the component. The component renders an <table> element using the provided attributes and children. It also supports rendering <tbody>, <thead>, <th>, <td> and <tr> tags.

Copyright 2025 Deirror. All rights reserved. Use of this source code is governed by a MIT-style license that can be found in the LICENSE file.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func TBody added in v0.5.0

func TBody(ps ...Props) templ.Component

func THead added in v0.5.0

func THead(ps ...Props) templ.Component

func Table

func Table(ps ...Props) templ.Component

func Td

func Td(ps ...Props) templ.Component

func Th

func Th(ps ...Props) templ.Component

func Tr added in v0.5.0

func Tr(ps ...Props) templ.Component

Types

type Props

type Props struct {
	props.Attrs

	Aria aria.Props
	Data data.Props
}

func (Props) AsTemplAttrs

func (p Props) AsTemplAttrs() templ.Attributes

Jump to