text

package
v0.5.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package text provides HTML text components. The Props type defines attributes for the component. The component renders an all text related tags element using the provided attributes and children.

Copyright 2025 Deirror. All rights reserved. Use of this source code is governed by a MIT-style license that can be found in the LICENSE file.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Abbr added in v0.2.0

func Abbr(ps ...Props) templ.Component

func B

func B(ps ...Props) templ.Component

func Blockquote

func Blockquote(ps ...Props) templ.Component

func Code

func Code(ps ...Props) templ.Component

func Dd

func Dd(ps ...Props) templ.Component

func Del added in v0.2.0

func Del(ps ...Props) templ.Component

func Dl

func Dl(ps ...Props) templ.Component

func Dt

func Dt(ps ...Props) templ.Component

func Em

func Em(ps ...Props) templ.Component

func H1

func H1(ps ...Props) templ.Component

func H2

func H2(ps ...Props) templ.Component

func H3

func H3(ps ...Props) templ.Component

func H4

func H4(ps ...Props) templ.Component

func H5

func H5(ps ...Props) templ.Component

func H6

func H6(ps ...Props) templ.Component

func I

func I(ps ...Props) templ.Component

func Ins added in v0.2.0

func Ins(ps ...Props) templ.Component

func Kbd added in v0.2.0

func Kbd(ps ...Props) templ.Component

func Li

func Li(ps ...Props) templ.Component

func Mark

func Mark(ps ...Props) templ.Component

func Ol

func Ol(ps ...Props) templ.Component

func P

func P(ps ...Props) templ.Component

func Pre

func Pre(ps ...Props) templ.Component

func S added in v0.2.0

func S(ps ...Props) templ.Component

func Small

func Small(ps ...Props) templ.Component

func Span

func Span(ps ...Props) templ.Component

func Strong

func Strong(ps ...Props) templ.Component

func Sub added in v0.2.0

func Sub(ps ...Props) templ.Component

func Sup added in v0.2.0

func Sup(ps ...Props) templ.Component

func U added in v0.2.0

func U(ps ...Props) templ.Component

func Ul

func Ul(ps ...Props) templ.Component

Types

type Props

type Props struct {
	props.Attrs

	Aria aria.Props
	Data data.Props
}

func (Props) AsTemplAttrs

func (p Props) AsTemplAttrs() templ.Attributes

Jump to