Documentation
¶
Overview ¶
Package text provides HTML text components. The Props type defines attributes for the component. The component renders an all text related tags element using the provided attributes and children.
Copyright 2025 Deirror. All rights reserved. Use of this source code is governed by a MIT-style license that can be found in the LICENSE file.
Index ¶
- func Abbr(ps ...Props) templ.Component
- func B(ps ...Props) templ.Component
- func Blockquote(ps ...Props) templ.Component
- func Code(ps ...Props) templ.Component
- func Dd(ps ...Props) templ.Component
- func Del(ps ...Props) templ.Component
- func Dl(ps ...Props) templ.Component
- func Dt(ps ...Props) templ.Component
- func Em(ps ...Props) templ.Component
- func H1(ps ...Props) templ.Component
- func H2(ps ...Props) templ.Component
- func H3(ps ...Props) templ.Component
- func H4(ps ...Props) templ.Component
- func H5(ps ...Props) templ.Component
- func H6(ps ...Props) templ.Component
- func I(ps ...Props) templ.Component
- func Ins(ps ...Props) templ.Component
- func Kbd(ps ...Props) templ.Component
- func Li(ps ...Props) templ.Component
- func Mark(ps ...Props) templ.Component
- func Ol(ps ...Props) templ.Component
- func P(ps ...Props) templ.Component
- func Pre(ps ...Props) templ.Component
- func S(ps ...Props) templ.Component
- func Small(ps ...Props) templ.Component
- func Span(ps ...Props) templ.Component
- func Strong(ps ...Props) templ.Component
- func Sub(ps ...Props) templ.Component
- func Sup(ps ...Props) templ.Component
- func U(ps ...Props) templ.Component
- func Ul(ps ...Props) templ.Component
- type Props
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Blockquote ¶
Types ¶
Click to show internal directories.
Click to hide internal directories.