Documentation
¶
Overview ¶
Package body provides helpers for building attributes for <body> elements in templ components. It wraps props.Attrs and exposes methods for safely passing attributes to templ elements.
Copyright 2025 Deirror. All rights reserved. Use of this source code is governed by a MIT-style license that can be found in the LICENSE file.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Props ¶
Props wraps props.Attrs to provide a typed container for <body> attributes.
func (Props) AsTemplAttrs ¶
func (p Props) AsTemplAttrs() templ.Attributes
AsTemplAttrs returns the wrapped attributes as templ.Attributes for use with templ elements.
Click to show internal directories.
Click to hide internal directories.