Documentation
¶
Overview ¶
Package html provides helpers for building HTML element attributes in templ components.
It combines general attributes (props.Attrs) with ARIA (accessible) and data-* attributes, allowing a single Props type to manage all common HTML element attributes.
Copyright 2025 Deirror. All rights reserved. Use of this source code is governed by a MIT-style license that can be found in the LICENSE file.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Props ¶
Props wraps props.Attrs and embeds aria.Props and data.Props to provide a single container for general, ARIA, and data-* attributes for any HTML element.
func (Props) AsTemplAttrs ¶
func (p Props) AsTemplAttrs() templ.Attributes
AsTemplAttrs combines all underlying attributes and returns templ.Attributes for use in templ elements.